@@ -33,8 +33,10 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include <dirent.h>
+
 #include <glib.h>
 #include <gio/gio.h>
+#include <gconf/gconf-client.h>
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "main.h"
@@ -952,7 +954,8 @@ get_temp_work_dir (const char *parent_folder)
 gboolean
 is_temp_work_dir (const char *dir)
 {
-	int i;
+	int   i;
+	char *folder;
 
 	if (strncmp (dir, "file://", 7) == 0)
 		dir = dir + 7;
@@ -960,14 +963,16 @@ is_temp_work_dir (const char *dir)
 		return FALSE;
 
 	for (i = 0; try_folder[i] != NULL; i++) {
-		const char *folder;
 
 		folder = ith_temp_folder_to_try (i);
 		if (strncmp (dir, folder, strlen (folder)) == 0)
-			if (strncmp (dir + strlen (folder), "/.fr-", 5) == 0)
+			if (strncmp (dir + strlen (folder), "/.fr-", 5) == 0) {
+				g_free (folder);
 				return TRUE;
+			}
 	}
 
+	g_free (folder);
 	return FALSE;
 }
 
