@@ -28,7 +28,7 @@
 #include <unistd.h>
 #include <gio/gio.h>
 
-#define MIME_TYPE_DIRECTORY "gnome-fs-directory"
+#define MIME_TYPE_DIRECTORY "folder"
 #define MIME_TYPE_ARCHIVE "application/x-archive"
 
 #define get_home_relative_path(x)        \
@@ -48,6 +48,7 @@ char *              get_dir_content_if_unique    (const char  *uri);
 gboolean            path_in_path                 (const char  *path_src,
 						  const char  *path_dest);
 goffset             get_file_size                (const char  *uri);
+goffset             get_file_size_for_path       (const char  *path);
 time_t              get_file_mtime               (const char  *uri);
 time_t              get_file_mtime_for_path      (const char  *path);
 time_t              get_file_ctime               (const char  *uri);
@@ -79,7 +80,7 @@ const char*         get_file_mime_type_for_path  (const char  *filename,
 guint64             get_dest_free_space          (const char  *path);
 gboolean            remove_directory             (const char  *uri);
 gboolean            remove_local_directory       (const char  *directory);
-char *              get_temp_work_dir            (void);
+char *              get_temp_work_dir            (const char  *parent_folder);
 gboolean            is_temp_work_dir             (const char *dir);
 gboolean            is_temp_dir                  (const char *dir);
 
@@ -97,7 +98,11 @@ char*               file_list__get_prev_field    (const char *line,
 						  int         field_n);
 gboolean            check_permissions            (const char *path,
 						  int         mode);
+gboolean            check_file_permissions       (GFile      *file,
+						  int         mode);
 gboolean 	    is_program_in_path		 (const char *filename);
+gboolean 	    is_program_available	 (const char *filename,
+						  gboolean    check);
 
 /* URI utils */
 
