@@ -1370,7 +1370,8 @@ create_tmp_base_dir (const char *base_dir,
 
 	dir = g_build_filename (temp_dir, "/", dest_dir, NULL);
 	debug (DEBUG_INFO, "symlink %s --> %s\n", dir, base_dir);
-	symlink (base_dir, dir);
+	if (symlink (base_dir, dir) != 0)
+		g_warning ("Could not create the symbolic link '%s', pointing to '%s'", dir, base_dir);
 
 	g_free (dir);
 	g_free (dest_dir);
